<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>DimDiametric</name>
    <message>
        <location filename="../DimDiametric.js" line="+57"/>
        <source>Choose arc or circle entity</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Proszę wskazać  łuk lub okrąg</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Dimension line location or angle</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Położenie lub kąt linii wymiarowej</translation>
    </message>
    <message>
        <location filename="../DimDiametricInit.js" line="+2"/>
        <source>&amp;Diametric</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Śre&amp;dnicowy</translatorcomment>
        <translation>Śre&amp;dnicowy</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Draw diametric dimension</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Rysuje wymiar średnicowy</translation>
    </message>
</context>
</TS>
